+++
title = "Paragraphs with ATTR_HTML"
tags = ["paragraph", "attr_html", "attr_css"]
draft = false
+++

Regular text.

<style>.red-text { color: red;  }</style>

<div class="red-text">
  <div></div>

Red text.

</div>

Regular text.

<style>.green-text { color: green;  }</style>

<div class="green-text">
  <div></div>

Green text.

</div>

Regular text.
